-- tamp_community.black_list definition

CREATE TABLE `black_list` (
   `id` bigint(32) NOT NULL AUTO_INCREMENT COMMENT 'id',
   `blocker` varchar(64) NOT NULL COMMENT '屏蔽发起人',
   `blocked_type` int(4) NOT NULL COMMENT '屏蔽类型，1：用户，2：内容',
   `blocked_id` varchar(64) NOT NULL COMMENT '被屏蔽的',
   `create_by` varchar(64) DEFAULT '',
   `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP,
   `update_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
   `delete_tag` int(3) NOT NULL DEFAULT '0',
   PRIMARY KEY (`id`),
   KEY `uk_blocker` (`blocker`),
   KEY `uk_blocked` (`blocked_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='黑名单';


-- tamp_community.collection definition

CREATE TABLE `collection` (
   `id` varchar(64) NOT NULL COMMENT 'id',
   `collection_type` int(4) NOT NULL COMMENT '类型 1:点赞主题，2：收藏主题 3、点赞评论',
   `user_id` varchar(64) NOT NULL COMMENT '用户id',
   `target_id` varchar(64) NOT NULL COMMENT '目标id',
   `collection_time` datetime DEFAULT NULL COMMENT '收藏时间',
   `uncollection_time` datetime DEFAULT NULL COMMENT '取消收藏时间',
   `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP,
   `update_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP,
   `delete_tag` int(3) NOT NULL DEFAULT '0',
   PRIMARY KEY (`id`),
   KEY `idx_author` (`user_id`) USING BTREE,
   KEY `idx_target` (`target_id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='收藏/点赞';


-- tamp_community.comment definition

CREATE TABLE `comment` (
  `id` bigint(32) NOT NULL AUTO_INCREMENT COMMENT 'id',
  `comment_id` varchar(64) NOT NULL COMMENT '评论主键Id',
  `comment_type` int(4) NOT NULL COMMENT '类型 1：评论',
  `content` varchar(1024) DEFAULT NULL COMMENT '文本内容',
  `author_id` varchar(64) NOT NULL COMMENT '作者id',
  `theme_id` varchar(64) DEFAULT NULL COMMENT '主题id',
  `parent_id` varchar(64) DEFAULT NULL COMMENT '一级评论id',
  `reply_id` varchar(64) DEFAULT NULL COMMENT '回复评论id',
  `is_pass` int(4) NOT NULL DEFAULT '0' COMMENT '是否通过 0：初始值  1：已通过（管理后台使用）',
  `report_status` int(4) NOT NULL DEFAULT '0' COMMENT '举报状态 0：未被举报  1:被举报 2：已处理',
  `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP,
  `update_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP,
  `delete_tag` int(3) NOT NULL DEFAULT '0',
  PRIMARY KEY (`id`),
  KEY `idx_author` (`author_id`) USING BTREE,
  KEY `idx_target` (`reply_id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='评论';


-- tamp_community.file_record definition

CREATE TABLE `file_record` (
    `id` bigint(32) NOT NULL AUTO_INCREMENT COMMENT 'id',
    `file_id` varchar(64) NOT NULL COMMENT '文件主键Id',
    `file_type` int(4) NOT NULL COMMENT '类型：1：图片',
    `file_name` varchar(64) NOT NULL COMMENT '文件名称',
    `file_oss_key` varchar(64) NOT NULL COMMENT '阿里云key',
    `preview_url` varchar(512) DEFAULT NULL COMMENT '预签名预览url',
    `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP,
    `update_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP,
    `delete_tag` int(3) NOT NULL DEFAULT '0',
    `ext_info` varchar(100) DEFAULT NULL,
    PRIMARY KEY (`id`),
    UNIQUE KEY `uk_logic` (`file_oss_key`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='上传文件';


-- tamp_community.follow_rel definition

CREATE TABLE `follow_rel` (
   `id` bigint(32) NOT NULL AUTO_INCREMENT COMMENT 'id',
   `follow_user_id` varchar(64) NOT NULL COMMENT '被关注的人id',
   `follower_id` varchar(64) NOT NULL COMMENT '粉丝id',
   `follow_time` datetime DEFAULT NULL COMMENT '关注时间',
   `unfollow_time` datetime DEFAULT NULL COMMENT '取消关注时间',
   `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP,
   `update_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
   `delete_tag` int(3) NOT NULL DEFAULT '0',
   PRIMARY KEY (`id`),
   UNIQUE KEY `uk_idol_follower` (`follow_user_id`,`follower_id`),
   KEY `idx_follower` (`follower_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='粉丝关系';


-- tamp_community.home_page definition

CREATE TABLE `home_page` (
  `id` bigint(32) NOT NULL AUTO_INCREMENT COMMENT 'id',
  `user_id` varchar(64) NOT NULL COMMENT '用户id',
  `head_img` varchar(256) NOT NULL COMMENT '头像url',
  `nick_name` varchar(32) NOT NULL COMMENT '昵称',
  `introduction` varchar(256) NOT NULL COMMENT '个人简介',
  `sex` int(3) DEFAULT NULL COMMENT '性别',
  `location` varchar(256) DEFAULT NULL COMMENT '地址',
  `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP,
  `update_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  `delete_tag` int(3) NOT NULL DEFAULT '0',
  PRIMARY KEY (`id`),
  UNIQUE KEY `uk_userId` (`user_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='个人主页';


-- tamp_community.news_feed definition

CREATE TABLE `news_feed` (
  `id` varchar(64) NOT NULL COMMENT '主键id',
  `content` varchar(10000) NOT NULL COMMENT '动态内容',
  `create_time` datetime NOT NULL COMMENT '创建时间',
  `create_by` varchar(64) NOT NULL COMMENT '创建人',
  `update_time` datetime DEFAULT NULL COMMENT '更新时间',
  `update_by` varchar(64) DEFAULT NULL COMMENT '更新人',
  `delete_tag` int(1) NOT NULL DEFAULT '0' COMMENT '删除标识:0 否 1：删除',
  `org_id` varchar(64) NOT NULL DEFAULT 'qimeng' COMMENT '机构qimeng',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='动态';


-- tamp_community.news_feed_like definition

CREATE TABLE `news_feed_like` (
  `id` varchar(64) NOT NULL,
  `news_feed_id` varchar(64) DEFAULT NULL,
  `create_time` datetime NOT NULL,
  `create_by` varchar(64) NOT NULL,
  `update_time` datetime DEFAULT NULL,
  `update_by` varchar(64) DEFAULT NULL,
  `delete_tag` int(1) NOT NULL COMMENT '删除标识  0：否 1：是',
  `org_id` varchar(64) NOT NULL DEFAULT 'qimeng' COMMENT '机构qimeng',
  PRIMARY KEY (`id`),
  KEY `idx_news_feed_id` (`news_feed_id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4;


-- tamp_community.news_feed_res definition

CREATE TABLE `news_feed_res` (
  `id` varchar(64) NOT NULL,
  `news_feed_id` varchar(64) DEFAULT NULL COMMENT '动态id',
  `rel_type` int(1) NOT NULL COMMENT '关联类型',
  `rel_id` varchar(255) NOT NULL COMMENT '关联id',
  `product_type` int(1) DEFAULT NULL COMMENT '产品类型   rel_type等于产品生效',
  `remark` varchar(5000) DEFAULT NULL COMMENT '备注说明',
  `create_time` datetime NOT NULL,
  `create_by` varchar(64) NOT NULL,
  `update_time` datetime DEFAULT NULL,
  `update_by` varchar(64) DEFAULT NULL,
  `delete_tag` int(1) DEFAULT NULL COMMENT '删除标识 0：否 1：是',
  `org_id` varchar(64) NOT NULL DEFAULT 'qimeng' COMMENT '机构qimeng',
  PRIMARY KEY (`id`),
  KEY `idx_news_feed_id` (`news_feed_id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4;


-- tamp_community.report_log definition

CREATE TABLE `report_log` (
  `id` bigint(32) NOT NULL AUTO_INCREMENT COMMENT 'id',
  `user_id` varchar(64) NOT NULL COMMENT '举报发起人',
  `report_type` int(4) NOT NULL COMMENT '举报类型，1：主题，2：评论 3、用户',
  `target_id` varchar(64) NOT NULL COMMENT '举报对象id',
  `target_user_id` varchar(64) NOT NULL COMMENT '举报对象作者id',
  `report_reason` varchar(64) DEFAULT NULL,
  `report_time` datetime NOT NULL COMMENT '上报时间',
  `deal_result` int(4) DEFAULT NULL COMMENT '处理结果 0：无操作 1：屏蔽 2：删除 ',
  `deal_user_id` int(4) DEFAULT NULL COMMENT '处理管理员',
  `deal_time` datetime DEFAULT NULL COMMENT '处理时间',
  `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP,
  `update_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  `delete_tag` int(3) NOT NULL DEFAULT '0',
  PRIMARY KEY (`id`),
  KEY `uk_user` (`user_id`),
  KEY `uk_report_target_id` (`target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='举报记录';


-- tamp_community.theme definition

CREATE TABLE `theme` (
  `id` bigint(32) NOT NULL AUTO_INCREMENT COMMENT 'id',
  `theme_id` varchar(64) NOT NULL COMMENT '主题主键Id',
  `title` varchar(64) DEFAULT NULL COMMENT '标题',
  `theme_type` int(4) NOT NULL COMMENT '类型 1：讨论无标题 2：长文有标题 3:转发',
  `content` text COMMENT '文本内容(json)，type：附件类型（108：文本，88:产品 3：直播 6：短视频 303：新版课程-视频，304: 新版课程-音频，109：单图（长文） 110：多图（讨论）），productType：基金类型（0 公募，1 私募，2 白名单，3 私有）',
  `discuss_content` varchar(256) DEFAULT NULL COMMENT '讨论中的文本',
  `author_id` varchar(64) NOT NULL COMMENT '作者id',
  `former_theme_id` varchar(64) DEFAULT NULL COMMENT '转发的主题',
  `topic_id` varchar(64) DEFAULT NULL COMMENT '所属的话题',
  `is_pass` int(4) NOT NULL DEFAULT '0' COMMENT '是否通过 0：初始值  1：已通过（管理后台使用）',
  `report_status` int(4) NOT NULL DEFAULT '0' COMMENT '举报状态 0：未被举报  1:被举报 2：已处理',
  `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP,
  `update_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  `delete_tag` int(3) NOT NULL DEFAULT '0' COMMENT '1：删除',
  PRIMARY KEY (`id`),
  KEY `idx_thmee_id` (`theme_id`),
  KEY `idx_author` (`author_id`),
  KEY `idx_former` (`former_theme_id`),
  KEY `idx_topic` (`topic_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='主题内容';


-- tamp_community.theme_attachment definition

CREATE TABLE `theme_attachment` (
  `id` varchar(64) NOT NULL COMMENT 'id',
  `theme_id` varchar(64) NOT NULL COMMENT '主题ID',
  `attach_type` int(4) NOT NULL COMMENT '附件类型：1:产品 2：直播 3：短视频 4：课程 5图片',
  `attach_id` varchar(64) NOT NULL COMMENT '附件对应的ID',
  `create_by` varchar(64) DEFAULT '',
  `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP,
  `update_by` varchar(64) DEFAULT '',
  `update_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP,
  `delete_tag` int(3) NOT NULL DEFAULT '0',
  `ext_info` varchar(100) DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `theme_id` (`theme_id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='主题附件';


-- tamp_community.topic definition

CREATE TABLE `topic` (
  `id` bigint(32) NOT NULL AUTO_INCREMENT COMMENT 'id',
  `topic_id` varchar(64) NOT NULL COMMENT '话题主键Id',
  `topic_title` varchar(64) NOT NULL COMMENT '话题名称',
  `is_top` int(4) NOT NULL COMMENT '是否置顶',
  `is_conceal` int(4) NOT NULL COMMENT '是否隐藏',
  `view_cnt_adjust` bigint(20) NOT NULL DEFAULT '0' COMMENT '浏览量调整基数',
  `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP,
  `update_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  `delete_tag` int(3) NOT NULL DEFAULT '0',
  PRIMARY KEY (`id`),
  UNIQUE KEY `uk_title` (`topic_title`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='话题';



CREATE TABLE `user_visit_statistics` (
                                         `id` bigint(32) unsigned NOT NULL AUTO_INCREMENT,
                                         `visitor_id` varchar(64) DEFAULT NULL,
                                         `ref_id` varchar(64) DEFAULT NULL,
                                         `ref_type` int(8) DEFAULT NULL,
                                         `total_duration` bigint(20) DEFAULT NULL,
                                         `first_visit_time` datetime DEFAULT NULL,
                                         `last_visit_time` datetime DEFAULT NULL,
                                         `total_visit` int(16) DEFAULT NULL,
                                         PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4;


CREATE TABLE `visit_summary` (
  `id` bigint(32) NOT NULL COMMENT 'id',
  `ident` varchar(64) DEFAULT NULL COMMENT 'session_id',
  `visitor_id` varchar(64) NOT NULL COMMENT '浏览者id',
  `author_id` varchar(64) DEFAULT NULL COMMENT '作者id',
  `ref_id` varchar(64) NOT NULL COMMENT '关联目标ID',
  `ref_type` int(8) NOT NULL COMMENT '关联目标类型 1：进入话题页 2：进入主题正文 3、用户查看首页-关注',
  `duration` int(16) DEFAULT NULL COMMENT '浏览时间 单位秒',
  `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP,
  `update_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP,
  `delete_tag` int(3) NOT NULL DEFAULT '0',
  PRIMARY KEY (`id`),
  KEY `idx_session` (`ident`) USING BTREE,
  KEY `idx_ref` (`ref_id`) USING BTREE,
  KEY `idx_visitor` (`visitor_id`) USING BTREE,
  KEY `idx_author` (`author_id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='浏览记录';

CREATE TABLE `topic_rank_log` (
                              `id` bigint(32) NOT NULL AUTO_INCREMENT COMMENT 'id',
                              `total_count` int NOT NULL COMMENT '总排序数量',
                              `page_number` int NOT NULL COMMENT '处理结果 0：无操作 1：屏蔽 2：删除 ',
                              `page_size` int NOT NULL  COMMENT '处理管理员',
                              `info` text  COMMENT '排序内容',
                              `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP,
                              `update_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
                              `delete_tag` int(3) NOT NULL DEFAULT '0',
                              PRIMARY KEY (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=9 DEFAULT CHARSET=utf8mb4 COMMENT='话题排序日志记录’';